@@ -2,13 +2,13 @@ from rwkvstic.rwkvMaster import RWKVMaster
 from rwkvstic.agnostic.samplers.numpy import npsample
 
 
-def initTFLiteFile(Path):
+def initTFLiteFile(path, tokenizer=None):
     import tensorflow.lite as tflite
 
     import tensorflow as tf
 
     interpreter = tflite.Interpreter(
-        model_path=Path)
+        model_path=path)
     interpreter.allocate_tensors()
 
     input_details = interpreter.get_input_details()
@@ -35,4 +35,4 @@ def initTFLiteFile(Path):
         [[0.01]*int(embed)]*int(layers), dtype=dtype)
 
     def initTensor(x): return tf.convert_to_tensor(x, dtype=dtype)
-    return RWKVMaster(model, emptyState, initTensor, npsample)
+    return RWKVMaster(model, emptyState, initTensor, npsample, tokenizer)
